==> haskell-warp-3.2.3-1-armv7h.pkg.tar.xz: usr/share/haskell/haskell-warp/register.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: warp
version: 3.2.3
id: warp-3.2.3-fdc49a5718602b1caa75db5ed6223617
key: warp_CSRjuVyRMAu0PF11TYg0Kh
license: MIT
maintainer: michael@snoyman.com
stability: Stable
homepage: http://github.com/yesodweb/wai
synopsis: A fast, light-weight web server for WAI applications.
description:
    HTTP\/1.0, HTTP\/1.1 and HTTP\/2 are supported.
    For HTTP\/2,  Warp supports direct and ALPN (in TLS)
    but not upgrade.
    API docs and the README are available at
    <http://www.stackage.org/package/warp>.
category: Web, Yesod
author: Michael Snoyman, Kazu Yamamoto, Matt Brown
exposed: True
exposed-modules:
    Network.Wai.Handler.Warp Network.Wai.Handler.Warp.Internal
hidden-modules: Network.Wai.Handler.Warp.Buffer
                Network.Wai.Handler.Warp.Conduit Network.Wai.Handler.Warp.Counter
                Network.Wai.Handler.Warp.Date Network.Wai.Handler.Warp.FdCache
                Network.Wai.Handler.Warp.File
                Network.Wai.Handler.Warp.FileInfoCache
                Network.Wai.Handler.Warp.HashMap Network.Wai.Handler.Warp.HTTP2
                Network.Wai.Handler.Warp.HTTP2.EncodeFrame
                Network.Wai.Handler.Warp.HTTP2.HPACK
                Network.Wai.Handler.Warp.HTTP2.Manager
                Network.Wai.Handler.Warp.HTTP2.Receiver
                Network.Wai.Handler.Warp.HTTP2.Request
                Network.Wai.Handler.Warp.HTTP2.Sender
                Network.Wai.Handler.Warp.HTTP2.Types
                Network.Wai.Handler.Warp.HTTP2.Worker
                Network.Wai.Handler.Warp.Header Network.Wai.Handler.Warp.IO
                Network.Wai.Handler.Warp.IORef Network.Wai.Handler.Warp.ReadInt
                Network.Wai.Handler.Warp.Recv Network.Wai.Handler.Warp.Request
                Network.Wai.Handler.Warp.RequestHeader
                Network.Wai.Handler.Warp.Response
                Network.Wai.Handler.Warp.ResponseHeader
                Network.Wai.Handler.Warp.Run Network.Wai.Handler.Warp.SendFile
                Network.Wai.Handler.Warp.Settings Network.Wai.Handler.Warp.Timeout
                Network.Wai.Handler.Warp.Types Network.Wai.Handler.Warp.Windows
                Paths_warp Network.Wai.Handler.Warp.MultiMap
trusted: False
import-dirs: /usr/lib/ghc-7.10.3/site-local/warp-3.2.3
library-dirs: /usr/lib/ghc-7.10.3/site-local/warp-3.2.3
data-dir: /usr/share/arm-linux-ghc-7.10.3/warp-3.2.3
hs-libraries: HSwarp-3.2.3-CSRjuVyRMAu0PF11TYg0Kh
depends:
    array-0.5.1.0-a4b4f31b03b7779670557ea46745a386
    auto-update-0.1.3-4edf36ce78b71bfaad1ce3737442c65f
    base-4.8.2.0-2f1f71a7fcf013cd47fd21f489064f9a
    blaze-builder-0.4.0.1-3daa45cd3be9618b289586d273c59e36
    bytestring-0.10.6.0-3b51e35daa3fe2a56ecd3687fb389cdc
    case-insensitive-1.2.0.5-6669cd7a393ccedc4f66c0a01b6f0e2f
    containers-0.5.6.2-169e53288f333dd2f0207994fd53822f
    ghc-prim-0.4.0.0-bf246eb9fdda7435f0c147a313ce59fb
    hashable-1.2.4.0-f83fcc5c92d0a1ea59927aca6baa3161
    http-date-0.0.6.1-fcef85ec3f020c9d6f587d45aa9f4919
    http-types-0.9-d392878af9c5e1b1993961dc71a9e177
    http2-1.5.0-69947b9c14d0dba49e2bbcb5dd3806c6
    iproute-1.7.0-38a0b7111fde75b34af10d9c12292092
    network-2.6.2.1-602ee4a12c5a174f6683a75303a065d3
    simple-sendfile-0.2.21-b4189a70d5e750749d989e840422f185
    stm-2.4.4.1-b43e402fc74ce6b0320fe4217e7e432d
    streaming-commons-0.1.15.1-aa72527d91e580265833d7825d2659ed
    text-1.2.2.0-2f82ea4adfdd656d9a8840ad2ee17cc0
    unix-2.7.1.0-a583968f8d5891c6bf334fddb26b19a6
    unix-compat-0.4.1.4-baa19ce04d0e8a47661438a80ea2aec8
    vault-0.3.0.6-8b1ddbd07c6eb1be1ee9aee781649e3c
    wai-3.2.0-61d8ab991e10dd6c5057d0dabf632d2a
    word8-0.1.2-9a296ac80618be494d93f29b398e749d
haddock-interfaces: /usr/share/doc/haskell-warp/html/warp.haddock
haddock-html: /usr/share/doc/haskell-warp/html
' | '/usr/bin/ghc-pkg' 'update' '-' '--global' '--no-user-package-db' "$@"

==> haskell-warp-3.2.3-5-armv7h.pkg.tar.xz: usr/share/haskell/haskell-warp/register.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: warp
version: 3.2.3
id: warp-3.2.3-e779983be81de2d2755ab5db7108dace
key: warp_04jMAHHVXkrBng0MoECBxW
license: MIT
maintainer: michael@snoyman.com
stability: Stable
homepage: http://github.com/yesodweb/wai
synopsis: A fast, light-weight web server for WAI applications.
description:
    HTTP\/1.0, HTTP\/1.1 and HTTP\/2 are supported.
    For HTTP\/2,  Warp supports direct and ALPN (in TLS)
    but not upgrade.
    API docs and the README are available at
    <http://www.stackage.org/package/warp>.
category: Web, Yesod
author: Michael Snoyman, Kazu Yamamoto, Matt Brown
exposed: True
exposed-modules:
    Network.Wai.Handler.Warp Network.Wai.Handler.Warp.Internal
hidden-modules: Network.Wai.Handler.Warp.Buffer
                Network.Wai.Handler.Warp.Conduit Network.Wai.Handler.Warp.Counter
                Network.Wai.Handler.Warp.Date Network.Wai.Handler.Warp.FdCache
                Network.Wai.Handler.Warp.File
                Network.Wai.Handler.Warp.FileInfoCache
                Network.Wai.Handler.Warp.HashMap Network.Wai.Handler.Warp.HTTP2
                Network.Wai.Handler.Warp.HTTP2.EncodeFrame
                Network.Wai.Handler.Warp.HTTP2.HPACK
                Network.Wai.Handler.Warp.HTTP2.Manager
                Network.Wai.Handler.Warp.HTTP2.Receiver
                Network.Wai.Handler.Warp.HTTP2.Request
                Network.Wai.Handler.Warp.HTTP2.Sender
                Network.Wai.Handler.Warp.HTTP2.Types
                Network.Wai.Handler.Warp.HTTP2.Worker
                Network.Wai.Handler.Warp.Header Network.Wai.Handler.Warp.IO
                Network.Wai.Handler.Warp.IORef Network.Wai.Handler.Warp.ReadInt
                Network.Wai.Handler.Warp.Recv Network.Wai.Handler.Warp.Request
                Network.Wai.Handler.Warp.RequestHeader
                Network.Wai.Handler.Warp.Response
                Network.Wai.Handler.Warp.ResponseHeader
                Network.Wai.Handler.Warp.Run Network.Wai.Handler.Warp.SendFile
                Network.Wai.Handler.Warp.Settings Network.Wai.Handler.Warp.Timeout
                Network.Wai.Handler.Warp.Types Network.Wai.Handler.Warp.Windows
                Paths_warp Network.Wai.Handler.Warp.MultiMap
trusted: False
import-dirs: /usr/lib/ghc-7.10.3/site-local/warp-3.2.3
library-dirs: /usr/lib/ghc-7.10.3/site-local/warp-3.2.3
data-dir: /usr/share/arm-linux-ghc-7.10.3/warp-3.2.3
hs-libraries: HSwarp-3.2.3-04jMAHHVXkrBng0MoECBxW
depends:
    array-0.5.1.0-a4b4f31b03b7779670557ea46745a386
    auto-update-0.1.3-4edf36ce78b71bfaad1ce3737442c65f
    base-4.8.2.0-2f1f71a7fcf013cd47fd21f489064f9a
    blaze-builder-0.4.0.1-3daa45cd3be9618b289586d273c59e36
    bytestring-0.10.6.0-3b51e35daa3fe2a56ecd3687fb389cdc
    case-insensitive-1.2.0.5-6669cd7a393ccedc4f66c0a01b6f0e2f
    containers-0.5.6.2-169e53288f333dd2f0207994fd53822f
    ghc-prim-0.4.0.0-bf246eb9fdda7435f0c147a313ce59fb
    hashable-1.2.4.0-f83fcc5c92d0a1ea59927aca6baa3161
    http-date-0.0.6.1-7c047cec0be0c1e5b3b7ae487c34e1e4
    http-types-0.9-d392878af9c5e1b1993961dc71a9e177
    http2-1.5.1-412270c75eeac0f5044d57dcaa27a692
    iproute-1.7.0-38a0b7111fde75b34af10d9c12292092
    network-2.6.2.1-602ee4a12c5a174f6683a75303a065d3
    simple-sendfile-0.2.21-b4189a70d5e750749d989e840422f185
    stm-2.4.4.1-b43e402fc74ce6b0320fe4217e7e432d
    streaming-commons-0.1.15.2-092d722155f2dc7f0b2e7a0dc037f30c
    text-1.2.2.0-2f82ea4adfdd656d9a8840ad2ee17cc0
    unix-2.7.1.0-a583968f8d5891c6bf334fddb26b19a6
    unix-compat-0.4.1.4-baa19ce04d0e8a47661438a80ea2aec8
    vault-0.3.0.6-8b1ddbd07c6eb1be1ee9aee781649e3c
    wai-3.2.0-61d8ab991e10dd6c5057d0dabf632d2a
    word8-0.1.2-9a296ac80618be494d93f29b398e749d
haddock-interfaces: /usr/share/doc/haskell-warp/html/warp.haddock
haddock-html: /usr/share/doc/haskell-warp/html
' | '/usr/bin/ghc-pkg' 'update' '-' '--global' '--no-user-package-db' "$@"
